==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextSupport__24BCSChild.h <==
// public class java.beans.beancontext.BeanContextSupport$BCSChild

// class file dependencies
// @dep_class 861a03e0754f962b java_beans_beancontext_BeanContextSupport__24BCSChild
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_
#define _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextSupport$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object;

typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$method$_init$1df597c7b3ea9bae(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object *, struct _jc_java_beans_beancontext_BeanContextSupport$object *);

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods {
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	java_beans_beancontext_BeanContextSupport__24BCSChild;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs {
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSChild;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object {
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextSupport__24BCSChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextSupport__24BCSChild.h <==
// public class java.beans.beancontext.BeanContextSupport$BCSChild

// class file dependencies
// @dep_class 861a03e0754f962b java_beans_beancontext_BeanContextSupport__24BCSChild
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_
#define _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextSupport$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object;

typedef struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$fields_struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$method$_init$1df597c7b3ea9bae(_jc_env *, struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object *, struct _jc_java_beans_beancontext_BeanContextSupport$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods {
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vmethods	java_beans_beancontext_BeanContextSupport__24BCSChild;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs {
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_refs	java_beans_beancontext_BeanContextSupport__24BCSChild;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$sub_nonrefs	java_beans_beancontext_BeanContextSupport__24BCSChild;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$object {
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextSupport__24BCSChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$vtype _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextSupport__24BCSChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextSupport__24BCSChild$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextSupport__24BCSChild_H_ */
